@@ -1,29 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
- *
- * @date   2006-09-15
- * @brief  Xmp manipulation methods
- *
- * @author Copyright (C) 2006-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2006-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2012 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Local includes
 
@@ -1069,7 +1049,7 @@ bool KExiv2::registerXmpNameSpace(const QString& uri, const QString& prefix)
     }
     catch( Exiv2::Error& e )
     {
-        Private::printExiv2ExceptionError(QString::fromLatin1("Cannot register a new Xmp namespace using Exiv2 "), e);
+        KExiv2Private::printExiv2ExceptionError(QString::fromLatin1("Cannot register a new Xmp namespace using Exiv2 "), e);
     }
     catch(...)
     {
@@ -1102,7 +1082,7 @@ bool KExiv2::unregisterXmpNameSpace(const QString& uri)
     }
     catch( Exiv2::Error& e )
     {
-        Private::printExiv2ExceptionError(QString::fromLatin1("Cannot unregister a new Xmp namespace using Exiv2 "), e);
+        KExiv2Private::printExiv2ExceptionError(QString::fromLatin1("Cannot unregister a new Xmp namespace using Exiv2 "), e);
     }
     catch(...)
     {
